** analysis requires coefplot, estout, and lincomest packages; run:
** ssc install coefplot
** ssc install lincomest
** ssc install estout

capture log close
clear
log using 2021-5-17-esarey-log.log, replace

*****************************************
* START WITH A DYADIC ANALYSIS
*****************************************

* create data set of challengers
use analysis-data-corrected-female, clear
drop if inc==1
rename * ch_*
rename ch_uniq_id uniq_id
save analysis-data-challengers, replace

* create dyadic data set
use analysis-data-corrected-female, clear
drop if inc==0
merge 1:1 uniq_id using analysis-data-challengers
save analysis-data-dyad, replace

* how many people voted for nobody?
tabulate vote ch_vote, col row cell

* create incumbent gender variable
gen female_i = female==1
replace female_i = . if female == .
label define female_lab 0 "Incumbent: Male" 1 "Incumbent: Female"
label values female_i female_lab
tab female_i female

* create challenger gender variable
gen ch_female_i = ch_female==1
replace ch_female_i = . if ch_female == .
label define ch_female_lab 0 "Challenger: Male" 1 "Challenger: Female"
label values ch_female_i ch_female_lab
tab ch_female_i ch_female

* create variable for whether incumbent bribed
gen bribe_i = corrupttreat > 1
replace bribe_i = . if corrupttreat == .
tab bribe_i corrupttreat
label define bribe_lab 0 "I: fought bribes" 1 "I: any bribe treatment"
label values bribe_i bribe_lab
label variable bribe_i "I: any bribe treatment"

* create variable for whether challenger bribed
gen ch_bribe_i = ch_corrupttreat > 1
replace ch_bribe_i = . if ch_corrupttreat == .
tab ch_bribe_i ch_corrupttreat
label define ch_bribe_lab 0 "C: fought bribes" 1 "C: any bribe treatment"
label values ch_bribe_i ch_bribe_lab
label variable ch_bribe_i "C: any bribe treatment"

* create variables for combinations of incumbent
* and challenger sex
gen IFCF = female_i == 1 & ch_female_i == 1
replace IFCF = . if female_i == . | ch_female_i == .
label define IFCF 0 " " 1 "Inc: Female, Ch: Female"
label values IFCF IFCF
label variable IFCF "Inc: Female, Ch: Female"
gen IFCM = female_i == 1 & ch_female_i == 0
replace IFCM = . if female_i == . | ch_female_i == .
label define IFCM 0 " " 1 "Inc: Female, Ch: Male"
label values IFCM IFCM
label variable IFCM "Inc: Female, Ch: Male"
gen IMCF = female_i == 0 & ch_female_i == 1
replace IMCF = . if female_i == . | ch_female_i == .
label define IMCF 0 " " 1 "Inc: Male, Ch: Female"
label values IMCF IMCF
label variable IMCF "Inc: Male, Ch: Female"

* create factor variable for combinations of incumbent
* and gender sex
gen genders = .
replace genders = 1 if IFCF == 1
replace genders = 2 if IFCM == 1
replace genders = 3 if IMCF == 1
replace genders = 0 if IFCF == 0 & IFCM == 0 & IMCF == 0
label variable genders "Gender of Candidates in Dyad"
label define genders 0 "Inc: M, Ch: M" 1 "Inc: F, Ch: F" 2 "Inc: F, Ch: M" 3 "Inc: M, Ch: F"
label values genders genders

* effect of incumbent/challenger sex, by bribe status
regress vote i.genders i.country [pw=weight1500] if(bribe_i == 1 & ch_bribe_i == 1), robust
regress vote i.genders i.country [pw=weight1500] if(bribe_i == 0 & ch_bribe_i == 1), robust
regress vote i.genders i.country [pw=weight1500] if(bribe_i == 1 & ch_bribe_i == 0), robust
regress vote i.genders i.country [pw=weight1500] if(bribe_i == 0 & ch_bribe_i == 0), robust

* effect of incumbent gender on vote for incumbent,
* by challenger bribe status
* with separate estimates for challenger sex
* fixing incumbent bribe status at "having bribed"
gen femaleXch_bribe = female*ch_bribe_i
regress vote i.female ch_bribe_i femaleXch_bribe i.country [pw=weight1500] if(bribe_i == 1 & ch_female_i==1), robust
est store linmod
lincomest 1.female
est store A
est restore linmod
lincomest 1.female + femaleXch_bribe
est store B
est restore linmod
regress vote i.female ch_bribe_i femaleXch_bribe i.country [pw=weight1500] if(bribe_i == 1 & ch_female_i==0), robust
est store linmod2
lincomest 1.female
est store AA
est restore linmod2
lincomest 1.female + femaleXch_bribe
est store BB
est restore linmod2

* calculate bonferroni correction 
display 100 - 5/4
display 100 - 20/4
* graph bonferroni-corrected CIs
coefplot (A, rename( (1) = "Challenger Fought Bribes") \ B, rename( (1) = "Challenger Accepted Bribes") \, label(Female Challenger)) (AA, rename( (1) = "Challenger Fought Bribes") \ BB, rename( (1) = "Challenger Accepted Bribes") \, label(Male Challenger)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote incumbent | incumbent female) - Pr(vote incumbent | incumbent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.5) aspect(0.8) levels(98.75 95)
graph export "dyadic-female-incumbent-bribe.pdf", replace

esttab linmod linmod2 using dyadic-female-incumbent-bribe.tex, replace drop(0.female 1.country) varwidth(35) coeflabels(1.female "Female Incumbent" ch_bribe_i "Challenger Bribed" femaleXch_bribe "Female Inc. X Challenger Bribed" 2.country "Chile" 3.country "Uruguay" _cons "Constant") mtitles("Male Challengers" "Female Challengers") nonumbers



* generate factor variable for dyadic treatment status
gen bribedyad = .
replace bribedyad = 0 if bribe_i == 0 & ch_bribe_i == 0
replace bribedyad = 1 if bribe_i == 1 & ch_bribe_i == 0
replace bribedyad = 2 if bribe_i == 0 & ch_bribe_i == 1
replace bribedyad = 3 if bribe_i == 1 & ch_bribe_i == 1
label variable bribedyad "Dyadic Bribery Treatment"
label define bribedyad 0 "Neither accepted bribe" 1 "Incumbent accepted bribe" 2 "Challenger accepted bribe" 3 "Both accepted bribe"
label values bribedyad bribedyad

* how many people saw at least one clean candidate?
tabulate bribedyad
display 100 - 57.42

* effect of incumbent gender on incumbent vote, 
* by dyadic treatment status
regress vote i.female#bribedyad i.country [pw=weight1500], robust
est store linmod
est store linmod_combo

* effect of being female, neither accepted bribe
lincomest 1.female#0.bribedyad
est store A
est restore linmod
* effect of being female, incumbent accepted bribe
lincomest 1.female#1.bribedyad - 0b.female#1.bribedyad
est store B
est restore linmod
* effect of being female, challenger accepted bribe
lincomest 1.female#2.bribedyad - 0b.female#2.bribedyad
est store C
est restore linmod
* effect of being female, both accepted bribe
lincomest 1.female#3.bribedyad - 0b.female#3.bribedyad
est store D
est restore linmod

* calculate bonferroni correction 
display 100 - 5/4
display 100 - 20/4
* graph bonferroni-corrected CIs
coefplot (A, label(Neither Accepted Bribes)) (B, label(Incumbent Accepted Bribes)) (C, label(Challenger Accepted Bribes)) (D, label(Both Accepted Bribes)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote incumbent | incumbent female) - Pr(vote incumbent | incumbent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(98.75 95)
graph export "dyadic-bribe-status.pdf", replace

* consolidate: incumbent bribes or not
* (collapse challenger bribery status)
gen femaleXbribe = female*bribe_i
regress vote i.female bribe_i femaleXbribe i.country [pw=weight1500], robust
est store linmod2 
lincomest 1.female
est store A
est restore linmod2
lincomest 1.female + femaleXbribe
est store B
est restore linmod2

* calculate bonferroni correction 
display 100 - 5/2
* graph bonferroni-corrected CIs
coefplot (A, label(Incumbent Fought Bribes)) (B, label(Incumbent Accepted Bribes)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote incumbent | incumbent female) - Pr(vote incumbent | incumbent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(97.5) xscale(range(-0.075 0.1)) xlabel(-0.075(0.025)0.1)
graph export "dyadic-incumbent-bribe-status.pdf", replace

esttab linmod2 linmod using "dyadic-models-by-treatment.tex", replace aic bic drop(0.female 0.female#0.bribedyad 1.country) varwidth(45) order(1.female bribe_i femaleXbribe 0.female#1.bribedyad 0.female#2.bribedyad 0.female#3.bribedyad 1.female#0.bribedyad 1.female#1.bribedyad 1.female#2.bribedyad 1.female#3.bribedyad 2.country 3.country _cons) coeflabels(0.female#1.bribedyad "Male Inc., Incumbent Accepted Bribe" 0.female#2.bribedyad "Male Inc., Challenger Accepted Bribe" 0.female#3.bribedyad "Male Inc., Both Accepted Bribe" 1.female#0.bribedyad "Female Inc., Neither Accepted Bribe" 1.female#1.bribedyad "Female Inc., Incumbent Accepted Bribe" 1.female#2.bribedyad "Female Inc., Challenger Accepted Bribe" 1.female#3.bribedyad "Female Inc., Both Accepted Bribe" 1.female "Female Incumbent" bribe_i "Incumbent Bribed" femaleXbribe "Female Inc. X Incumbent Bribed" 2.country "Chile" 3.country "Uruguay" _cons "Constant") nomtitles


* create respondent gender variable
gen r_female_i = r_female==1
replace r_female_i = . if r_female==.
label define r_female_lab 0 "Respondent: Male" 1 "Respondent: Female"
label values r_female_i r_female_lab
tab r_female_i r_female

* effect of respondent gender on incumbent vote, 
* by dyadic treatment status
regress vote i.r_female#bribedyad i.country [pw=weight1500], robust
est store linmod

* effect of being female, neither accepted bribe
lincomest 1.r_female#0.bribedyad
est store A
est restore linmod
* effect of being female, incumbent accepted bribe
lincomest 1.r_female#1.bribedyad - 0b.r_female#1.bribedyad
est store B
est restore linmod
* effect of being female, challenger accepted bribe
lincomest 1.r_female#2.bribedyad - 0b.r_female#2.bribedyad
est store C
est restore linmod
* effect of being female, both accepted bribe
lincomest 1.r_female#3.bribedyad - 0b.r_female#3.bribedyad
est store D
est restore linmod

* calculate bonferroni correction 
display 100 - 5/4
display 100 - 20/4
* graph bonferroni-corrected CIs
coefplot (A, label(Neither Accepted Bribes)) (B, label(Incumbent Accepted Bribes)) (C, label(Challenger Accepted Bribes)) (D, label(Both Accepted Bribes)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote incumbent | respondent female) - Pr(vote incumbent | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(98.75 95)
graph export "dyadic-bribe-respondent.pdf", replace


* consolidate: incumbent bribes or not
* (collapse challenger bribery status)
gen r_femaleXbribe = r_female*bribe_i
regress vote i.r_female bribe_i r_femaleXbribe i.country [pw=weight1500], robust
est store linmod2
lincomest 1.r_female
est store A
est restore linmod2
lincomest 1.r_female + r_femaleXbribe
est store B
est restore linmod2

* calculate bonferroni correction 
display 100 - 5/2
display 100 - 20/2
* graph bonferroni-corrected CIs
coefplot (A, label(Incumbent Fought Bribes)) (B, label(Incumbent Accepted Bribes)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote incumbent | respondent female) - Pr(vote incumbent | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(97.5 90) xscale(range(-.1 .05)) xlabel(-.1(0.025)0.05)
graph export "dyadic-bribe-simple.pdf", replace

esttab linmod2 linmod using "dyadic-models-by-respondent.tex", replace aic bic varwidth(45) drop(0.r_female#0.bribedyad 0.r_female 1.country) order(1.r_female bribe_i r_femaleXbribe 0.r_female#1.bribedyad 0.r_female#2.bribedyad 0.r_female#3.bribedyad 1.r_female#0.bribedyad 1.r_female#1.bribedyad 1.r_female#2.bribedyad 1.r_female#3.bribedyad 1.country 2.country _cons) coeflabels(0.r_female#1.bribedyad "Male respondent, Incumbent bribed" 0.r_female#2.bribedyad "Male respondent, Challenger bribed" 0.r_female#3.bribedyad "Male respondent, Both bribed" 1.r_female#0.bribedyad "Female respondent, Neither bribed" 1.r_female#1.bribedyad "Female respondent, Incumbent bribed" 1.r_female#2.bribedyad "Female respondent, Challenger bribed" 1.r_female#3.bribedyad "Female respondent, Both bribed" 1.r_female "Female respondent" bribe_i "Incumbent bribed" r_femaleXbribe "Female respondent X Incumbent bribed" 2.country "Chile" 3.country "Uruguay" _cons "Constant") nomtitles



* effect of incumbent gender on incumbent vote, 
* by dyadic treatment status
* male respondents only
regress vote i.female#bribedyad i.country [pw=weight1500] if(r_female==0), robust
est store linmod

* effect of being female, neither accepted bribe
lincomest 1.female#0.bribedyad
est store A
est restore linmod
* effect of being female, incumbent accepted bribe
lincomest 1.female#1.bribedyad - 0b.female#1.bribedyad
est store B
est restore linmod
* effect of being female, challenger accepted bribe
lincomest 1.female#2.bribedyad - 0b.female#2.bribedyad
est store C
est restore linmod
* effect of being female, both accepted bribe
lincomest 1.female#3.bribedyad - 0b.female#3.bribedyad
est store D
est restore linmod

* female respondents only
regress vote i.female#bribedyad i.country [pw=weight1500] if(r_female==1), robust
est store linmod2

* effect of being female, neither accepted bribe
lincomest 1.female#0.bribedyad
est store AA
est restore linmod2
* effect of being female, incumbent accepted bribe
lincomest 1.female#1.bribedyad - 0b.female#1.bribedyad
est store BB
est restore linmod2
* effect of being female, challenger accepted bribe
lincomest 1.female#2.bribedyad - 0b.female#2.bribedyad
est store CC
est restore linmod2
* effect of being female, both accepted bribe
lincomest 1.female#3.bribedyad - 0b.female#3.bribedyad
est store DD
est restore linmod2

* calculate bonferroni correction 
display 100 - 5/8
display 100 - 20/8
* graph bonferroni-corrected CIs
coefplot (A, rename((1) = "Male Respondents") \ AA, rename((1) = "Female Respondents")\, label(Neither Accepted Bribes)) (B, rename((1) = "Male Respondents") \ BB, rename((1) = "Female Respondents")\, label(Incumbent Accepted Bribes)) (C, rename((1) = "Male Respondents") \ CC, rename((1) = "Female Respondents")\, label(Challenger Accepted Bribes)) (D, rename((1) = "Male Respondents") \ DD, rename((1) = "Female Respondents")\, label(Both Accepted Bribes)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote incumbent | incumbent female) - Pr(vote incumbent | incumbent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) legend(size(small)) ysize(2) xsize(3.1) aspect(0.8) levels(99.375 97.5) xscale(range(-.25 .35)) xlabel(-.25(0.05)0.35)
graph export "dyadic-bribe-status-by-respondent.pdf", replace

esttab linmod linmod2 linmod_combo using "dyadic-models-by-treatment-and-respondent.tex", replace drop(0.female#0.bribedyad 1.country) varwidth(45) order(0.female#1.bribedyad 0.female#2.bribedyad 0.female#3.bribedyad 1.female#0.bribedyad 1.female#1.bribedyad 1.female#2.bribedyad 1.female#3.bribedyad 2.country 3.country _cons) coeflabels(0.female#1.bribedyad "Male Inc., Incumbent Accepted Bribe" 0.female#2.bribedyad "Male Inc., Challenger Accepted Bribe" 0.female#3.bribedyad "Male Inc., Both Accepted Bribe" 1.female#0.bribedyad "Female Inc., Neither Accepted Bribe" 1.female#1.bribedyad "Female Inc., Incumbent Accepted Bribe" 1.female#2.bribedyad "Female Inc., Challenger Accepted Bribe" 1.female#3.bribedyad "Female Inc., Both Accepted Bribe" 2.country "Chile" 3.country "Uruguay" _cons "Constant") mtitles("Male Respondents" "Female Respondents" "All Respondents")




***************************************************
* NOW CONDUCT A MONADIC ANALYSIS

use analysis-data-corrected-female, clear

regress vote i.corrupttreat i.female i.country [pw=weight1500], cl(uniq_id)

***** Question 1: Are female candidates under suspicion of bribery
***** judged more harshly?

* create numeric female variable
gen female_i = female==1
replace female_i = . if female==.
label define female_lab 0 "Candidate: Male" 1 "Candidate: Female"
label values female_i female_lab
tab female_i female

tab corrupttreat female

******************************************************
* replicate LeFoulon/Householder analysis, Figure 2
******************************************************
* BRIBE TREATMENT
* Uruguay
regress vote female_i if(country==3 & corrupttreat==2), cl(uniq_id)
lincomest female_i
est store A1
* Argentina
regress vote female_i if(country==1 & corrupttreat==2), cl(uniq_id)
lincomest female_i
est store A2
* Chile
regress vote female_i if(country==2 & corrupttreat==2), cl(uniq_id)
lincomest female_i
est store A3
* test for differences
regress vote i.female#i.country if(corrupttreat==2), cl(uniq_id)
estat ic
est store MA1
regress vote i.female if(corrupttreat==2), cl(uniq_id)
estat ic
est store MA2
esttab MA1 MA2, aic bic order(0.female#2.country 0.female#3.country 1.female 1.female#1.country 1.female#2.country 1.female#3.country _cons) coeflabels(0.female#2.country "Chile" 0.female#3.country "Uruguay" 1.female#1.country "Argentina x Female" 1.female#2.country "Chile x Female" 1.female#3.country "Uruguay x Female" 1.female "Candidate: Female" _cons "Intercept (Baseline: Argentina)") drop(0.female#1.country 0.female) varwidth(35)

* BRIBE AND SIDE BENEFITS
* Uruguay
regress vote female_i if(country==3 & corrupttreat==4), cl(uniq_id)
lincomest female_i
est store B1
* Argentina
regress vote female_i if(country==1 & corrupttreat==4), cl(uniq_id)
lincomest female_i
est store B2
* Chile
regress vote female_i if(country==2 & corrupttreat==4), cl(uniq_id)
lincomest female_i
est store B3
* test for differences
regress vote i.female#i.country if(corrupttreat==4), cl(uniq_id)
estat ic
est store MB1
regress vote i.female if(corrupttreat==4), cl(uniq_id)
estat ic
est store MB2
esttab MB1 MB2, aic bic order(0.female#2.country 0.female#3.country 1.female 1.female#1.country 1.female#2.country 1.female#3.country _cons) coeflabels(0.female#2.country "Chile" 0.female#3.country "Uruguay" 1.female#1.country "Argentina x Female" 1.female#2.country "Chile x Female" 1.female#3.country "Uruguay x Female" 1.female "Candidate: Female" _cons "Intercept (Baseline: Argentina)") drop(0.female#1.country 0.female) varwidth(35)


* BRIBE AND WIDESPREAD
* Uruguay
regress vote female_i if(country==3 & corrupttreat==3), cl(uniq_id)
lincomest female_i
est store C1
* Argentina
regress vote female_i if(country==1 & corrupttreat==3), cl(uniq_id)
lincomest female_i
est store C2
* Chile
regress vote female_i if(country==2 & corrupttreat==3), cl(uniq_id)
lincomest female_i
est store C3
* test for differences
regress vote i.female#i.country if(corrupttreat==3), cl(uniq_id)
estat ic
est store MC1
regress vote i.female if(corrupttreat==3), cl(uniq_id)
estat ic
est store MC2
esttab MC1 MC2, aic bic order(0.female#2.country 0.female#3.country 1.female 1.female#1.country 1.female#2.country 1.female#3.country _cons) coeflabels(0.female#2.country "Chile" 0.female#3.country "Uruguay" 1.female#1.country "Argentina x Female" 1.female#2.country "Chile x Female" 1.female#3.country "Uruguay x Female" 1.female "Candidate: Female" _cons "Intercept (Baseline: Argentina)") drop(0.female#1.country 0.female) varwidth(35)

* replicate LeFoulon/Householder analysis, Figure 2
* FIGHT CORRUPTION
* Uruguay
regress vote female_i if(country==3 & corrupttreat==1), cl(uniq_id)
lincomest female_i
est store D1
* Argentina
regress vote female_i if(country==1 & corrupttreat==1), cl(uniq_id)
lincomest female_i
est store D2
* Chile
regress vote female_i if(country==2 & corrupttreat==1), cl(uniq_id)
lincomest female_i
est store D3

* test for differences
regress vote i.female#i.country if(corrupttreat==3), cl(uniq_id)
estat ic
est store MD1
regress vote i.female if(corrupttreat==3), cl(uniq_id)
estat ic
est store MD2
esttab MD1 MD2, aic bic order(0.female#2.country 0.female#3.country 1.female 1.female#1.country 1.female#2.country 1.female#3.country _cons) coeflabels(0.female#2.country "Chile" 0.female#3.country "Uruguay" 1.female#1.country "Argentina x Female" 1.female#2.country "Chile x Female" 1.female#3.country "Uruguay x Female" 1.female "Candidate: Female" _cons "Intercept (Baseline: Argentina)") drop(0.female#1.country 0.female) varwidth(35)

esttab MA1 MA2 MB1 MB2 MC1 MC2 MD1 MD2 using "pooltest.tex", replace aic bic order(0.female#2.country 0.female#3.country 1.female 1.female#1.country 1.female#2.country 1.female#3.country _cons) coeflabels(0.female#2.country "Chile" 0.female#3.country "Uruguay" 1.female#1.country "Argentina x Female" 1.female#2.country "Chile x Female" 1.female#3.country "Uruguay x Female" 1.female "Candidate: Female" _cons "Intercept (Baseline: Argentina)") drop(0.female#1.country 0.female) varwidth(35) mgroups("Bribes" "Bribes w/ Side Benefits" "Widespread Bribes" "Fought Bribes", pattern(1 0 1 0 1 0 1 0)prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles nonotes addnotes("\textit{t} statistics in parentheses. Standard errors clustered by subject." "* p<0.05, ** p<0.01, *** p<0.001")

coefplot (A1, rename( (1) = "Uruguay") \ A2, rename( (1) = "Argentina") \ A3, rename( (1) = "Chile") \, label(Bribes)) (B1, rename( (1) = "Uruguay") \ B2, rename( (1) = "Argentina") \ B3, rename( (1) = "Chile") \, label(Bribes and Side Benefits)) (C1, rename( (1) = "Uruguay") \ C2, rename( (1) = "Argentina") \ C3, rename( (1) = "Chile") \, label(Bribes and Widespread)) (D1, rename( (1) = "Uruguay") \ D2, rename( (1) = "Argentina") \ D3, rename( (1) = "Chile") \, label(Fight Corruption)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.5) aspect(0.8) levels(95)

coefplot (A1, rename( (1) = "Bribe") \ B1, rename( (1) = "Bribe and Side Benefits") \ C1, rename( (1) = "Bribe and Widespread") \ D1, rename( (1) = "Fight Corruption") \, label(Uruguay)) (A2, rename( (1) = "Bribe") \ B2, rename( (1) = "Bribe and Side Benefits") \ C2, rename( (1) = "Bribe and Widespread") \ D2, rename( (1) = "Fight Corruption") \, label(Argentina)) (A3, rename( (1) = "Bribe") \ B3, rename( (1) = "Bribe and Side Benefits") \ C3, rename( (1) = "Bribe and Widespread") \ D3, rename( (1) = "Fight Corruption") \, label(Chile)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small) rows(1)) ysize(3) xsize(4.5) aspect(0.8) levels(95 90) xlabel(-0.3(0.05)0.3, labsize(small))

graph export "lefoulon-householder-replication.pdf", replace

******************************************************
* replicate Klasnua, Lupu, and Tucker, Figure 1,
* gender subcomponent
******************************************************

est clear
regress vote female_i
est store A
coefplot (A, label("Female")), drop(_cons) scheme(s1manual) ytitle("") xtitle("Effect on Pr(Voting for Candidate)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = "Female") legend(off) ysize(1) xsize(1.25) aspect(0.8) levels(95 90) xlabel(-0.025(0.025)0.05, labsize(small))

graph export "klasna-et-al-replication.pdf", replace



* draw a graph comparing male and female candidate support in every treatment condition
* first, create basic regressions (for CIs)
regress vote female_i if(corrupttreat==1) [pw=weight1500], cl(uniq_id)
est store A
regress vote female_i if(corrupttreat==2) [pw=weight1500], cl(uniq_id)
est store B
regress vote female_i if(corrupttreat==3) [pw=weight1500], cl(uniq_id)
est store C
regress vote female_i if(corrupttreat==4) [pw=weight1500], cl(uniq_id)
est store D

* now, compare mean support for women vs. mean support for men 
* with 95% confidence intervals 
* calculate bonferroni correction 
display 100 - 5/4
* graph bonferroni-corrected CIs
coefplot (A, label(Resist Bribes)) (B, label(Bribes Only)) (C, label(Bribes Common)) (D, label(Bribes with Jobs)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(98.75)
graph export "candidate-gender-descrip.pdf", replace

regress vote i.corrupttreat##female_i i.country [pw=weight1500], cl(uniq_id)
est store linmod

* create table of result
esttab linmod, label nobaselevels interaction(" X ") varwidth(40) nomtitles

* formal test shows that all interactions between treatment and female are indistinguishable
test 2.corrupttreat#1.female_i == 4.corrupttreat#1.female_i == 3.corrupttreat#1.1.female_i
* interaction between all forms of bribery and female is similar
lincom 2.corrupttreat#1.female_i - 3.corrupttreat#1.female_i
lincom 2.corrupttreat#1.female_i - 4.corrupttreat#1.female_i
lincom 3.corrupttreat#1.female_i - 4.corrupttreat#1.female_i
* calculate effect of being female in each treatment
lincomest 1.female_i
est store AAA
est restore linmod
lincomest 1.female_i + 2.corrupttreat#1.female_i
est store BBB
est restore linmod
lincomest 1.female_i + 3.corrupttreat#1.female_i
est store CCC
est restore linmod
lincomest 1.female_i + 4.corrupttreat#1.female_i
est store DDD
est restore linmod
* calculate bonferroni correction 
display 100 - 5/4
* graph bonferroni-corrected CIs
coefplot (AAA, label(Resist Bribes)) (BBB, label(Bribes Only)) (CCC, label(Bribes Common)) (DDD, label(Bribes with Jobs)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(98.75)
graph export "candidate-gender-regression.pdf", replace

* combine all forms of bribery, interact with female judgment
gen bribe_i = corrupttreat > 1
replace bribe_i = . if corrupttreat == .
tab bribe_i corrupttreat
label define bribe_lab 0 "fought bribes" 1 "any bribe treatment"
label values bribe_i bribe_lab
label variable bribe_i "any bribe treatment"
gen bribeXfemale = bribe_i * female_i
label variable bribeXfemale "Any bribe treatment X C: Female"

* women candidates are consistently punished more harshly than men 
* when under suspicion of bribery
regress vote i.corrupttreat i.female_i bribeXfemale i.country [pw=weight1500], cl(uniq_id)
est store linmod2
lincomest 1.female_i
est store A
est restore linmod2
lincomest 1.female_i + bribeXfemale
est store B
est restore linmod2
* calculate bonferroni correction 
display 100 - 5/2
* graph bonferroni-corrected CIs
coefplot (A, label(Resist Bribes)) (B, label(All Bribery Treatments)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(97.5) xscale(range(-0.08 0.08)) xlabel(-0.08(0.02)0.08)
graph export "candidate-gender-simple-regression.pdf", replace

esttab linmod linmod2, label nobaselevels interaction(" X ") varwidth(40) nomtitles order(2.corrupttreat 3.corrupttreat 4.corrupttreat 1.female_i 2.corrupttreat#1.female_i 3.corrupttreat#1.female_i 4.corrupttreat#1.female_i bribeXfemale)


* alternative specification: not as good, as it combines
* intercepts for all bribery treatments
reg vote bribe_i female_i bribeXfemale i.country [pw=weight1500], cl(uniq_id)
lincom female_i + bribeXfemale






***** Question 2: Do female respondents judge bribery more harshly?

* create simple/numeric variable for respondent gender
gen r_female_i = r_female==1
replace r_female_i = . if r_female==.
label define female_r_lab 0 "Respondent: Male" 1 "Respondent: Female"
label values r_female_i female_r_lab
tab r_female_i r_female

* draw a graph comparing male and female respondents in every treatment condition
* first, create basic regressions (for CIs)
regress vote r_female_i if(corrupttreat==1) [pw=weight1500], cluster(uniq_id)
est store A
regress vote r_female_i if(corrupttreat==2) [pw=weight1500], cluster(uniq_id)
est store B
regress vote r_female_i if(corrupttreat==3) [pw=weight1500], cluster(uniq_id)
est store C
regress vote r_female_i if(corrupttreat==4) [pw=weight1500], cluster(uniq_id)
est store D

* now, compare mean support for women vs. mean support for men 
* with 95% confidence intervals
* calculate bonferroni correction 
display 100 - 5/4
* graph bonferroni-corrected CIs 
coefplot (A, label(Resist Bribes)) (B, label(Bribes Only)) (C, label(Bribes Common)) (D, label(Bribes with Jobs)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote for candidate | respondent female) - Pr(vote for candidate | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(98.75)
graph export "respondent-gender-descrip.pdf", replace

* are the three bribery treatments distinguishable in terms of their 
* effect on women?
regress vote i.corrupttreat##r_female_i i.country [pw=weight1500], cl(uniq_id)
est store linmod3

* calculate effect of being female in each treatment
lincomest 1.r_female_i
est store A
est restore linmod3
lincomest 1.r_female_i + 2.corrupttreat#1.r_female_i
est store B
est restore linmod3
lincomest 1.r_female_i + 3.corrupttreat#1.r_female_i
est store C
est restore linmod3
lincomest 1.r_female_i + 4.corrupttreat#1.r_female_i
est store D
est restore linmod3
* calculate bonferroni correction 
display 100 - 5/4
* graph bonferroni-corrected CIs
coefplot (A, label(Resist Bribes)) (B, label(Bribes Only)) (C, label(Bribes Common)) (D, label(Bribes with Jobs)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote for candidate | respondent female) - Pr(vote for candidate | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(98.75)
graph export "respondent-gender-regression.pdf", replace

* F-test says we cannot reject the null that all interactions are equal
* however, it is rather close!
test 2.corrupttreat#1.r_female_i == 4.corrupttreat#1.r_female_i == 3.corrupttreat#1.r_female_i
* interaction between all forms of bribery and female is similar, but
* the men/women difference does tend to be a bit bigger in the basic bribes treatment
* compared to the bribes common treatment
lincom 2.corrupttreat#1.r_female_i - 3.corrupttreat#1.r_female_i
lincom 2.corrupttreat#1.r_female_i - 4.corrupttreat#1.r_female_i
lincom 3.corrupttreat#1.r_female_i - 4.corrupttreat#1.r_female_i

gen bribeXr_female = bribe_i * r_female_i
label variable bribeXr_female "Any bribe treatment X R: Female"
regress vote i.corrupttreat i.r_female_i bribeXr_female i.country [pw=weight1500], cl(uniq_id)
est store linmod4
* answer below, in lincom: female respondents DO judge bribery allegations more harshly,
* but the magnitude isn't that different--it's just a more precise estimate
lincomest 1.r_female_i
est store A 
est restore linmod4
lincomest 1.r_female_i + bribeXr_female
est store B
* calculate bonferroni correction 
display 100 - 5/4
* graph bonferroni-corrected CIs
coefplot (A, label(Resist Bribes)) (B, label(All Bribery Treatments)), drop(_cons) scheme(s1manual) ylabel(,nolabels) ytitle("") xtitle("Pr(vote for candidate | respondent female) - Pr(vote for candidate | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(3.5) aspect(0.8) levels(97.5) xlabel(#7)
graph export "respondent-gender-simple-regression.pdf", replace

esttab linmod linmod2 linmod3 linmod4, replace label nobaselevels interaction(" X ") varwidth(50) nomtitles order(2.corrupttreat 3.corrupttreat 4.corrupttreat 1.female_i 2.corrupttreat#1.female_i 3.corrupttreat#1.female_i 4.corrupttreat#1.female_i bribeXfemale 1.r_female_i 2.corrupttreat#1.r_female_i 3.corrupttreat#1.r_female_i 4.corrupttreat#1.r_female_i bribeXr_female) coeflabels(2.corrupttreat#1.female_i "Bribes X C: Female" 3.corrupttreat#1.female_i "Bribes common X C: Female" 4.corrupttreat#1.female_i "Bribes but jobs X C: Female" 2.corrupttreat#1.r_female_i "Bribes X R: Female" 3.corrupttreat#1.r_female_i "Bribes common X R: Female" 4.corrupttreat#1.r_female_i "Bribes but jobs X R: Female")

* alternative specification (not as good; combines all bribe treatment intercepts)
reg vote bribe_i r_female_i bribeXr_female i.country [pw=weight1500], cl(uniq_id)
* same answer
lincom r_female_i + bribeXr_female

*** perform pooling test for respondent behavior
* BRIBE TREATMENT
* Uruguay
regress vote r_female_i if(country==3 & corrupttreat==2), cl(uniq_id)
lincomest r_female_i
est store A1
* Argentina
regress vote r_female_i if(country==1 & corrupttreat==2), cl(uniq_id)
lincomest r_female_i
est store A2
* Chile
regress vote r_female_i if(country==2 & corrupttreat==2), cl(uniq_id)
lincomest r_female_i
est store A3
* test for differences
regress vote i.r_female#i.country if(corrupttreat==2), cl(uniq_id)
estat ic
est store MA1
regress vote i.r_female if(corrupttreat==2), cl(uniq_id)
estat ic
est store MA2
esttab MA1 MA2, aic bic order(0.r_female#2.country 0.r_female#3.country 1.r_female 1.r_female#1.country 1.r_female#2.country 1.r_female#3.country _cons) coeflabels(0.r_female#2.country "Chile" 0.r_female#3.country "Uruguay" 1.r_female#1.country "Argentina x Female" 1.r_female#2.country "Chile x Female" 1.r_female#3.country "Uruguay x Female" 1.r_female "Respondent: Female" _cons "Intercept (Baseline: Argentina)") drop(0.r_female#1.country 0.r_female) varwidth(35)

* BRIBE AND SIDE BENEFITS
* Uruguay
regress vote r_female_i if(country==3 & corrupttreat==4), cl(uniq_id)
lincomest r_female_i
est store B1
* Argentina
regress vote r_female_i if(country==1 & corrupttreat==4), cl(uniq_id)
lincomest r_female_i
est store B2
* Chile
regress vote r_female_i if(country==2 & corrupttreat==4), cl(uniq_id)
lincomest r_female_i
est store B3
* test for differences
regress vote i.r_female#i.country if(corrupttreat==4), cl(uniq_id)
estat ic
est store MB1
regress vote i.r_female if(corrupttreat==4), cl(uniq_id)
estat ic
est store MB2
esttab MB1 MB2, aic bic order(0.r_female#2.country 0.r_female#3.country 1.r_female 1.r_female#1.country 1.r_female#2.country 1.r_female#3.country _cons) coeflabels(0.r_female#2.country "Chile" 0.r_female#3.country "Uruguay" 1.r_female#1.country "Argentina x Female" 1.r_female#2.country "Chile x Female" 1.r_female#3.country "Uruguay x Female" 1.r_female "Respondent: Female" _cons "Intercept (Baseline: Argentina)") drop(0.r_female#1.country 0.r_female) varwidth(35)


* BRIBE AND WIDESPREAD
* Uruguay
regress vote r_female_i if(country==3 & corrupttreat==3), cl(uniq_id)
lincomest r_female_i
est store C1
* Argentina
regress vote r_female_i if(country==1 & corrupttreat==3), cl(uniq_id)
lincomest r_female_i
est store C2
* Chile
regress vote r_female_i if(country==2 & corrupttreat==3), cl(uniq_id)
lincomest r_female_i
est store C3
* test for differences
regress vote i.r_female#i.country if(corrupttreat==3), cl(uniq_id)
estat ic
est store MC1
regress vote i.r_female if(corrupttreat==3), cl(uniq_id)
estat ic
est store MC2
esttab MC1 MC2, aic bic order(0.r_female#2.country 0.r_female#3.country 1.r_female 1.r_female#1.country 1.r_female#2.country 1.r_female#3.country _cons) coeflabels(0.r_female#2.country "Chile" 0.r_female#3.country "Uruguay" 1.r_female#1.country "Argentina x Female" 1.r_female#2.country "Chile x Female" 1.r_female#3.country "Uruguay x Female" 1.r_female "Respondent: Female" _cons "Intercept (Baseline: Argentina)") drop(0.r_female#1.country 0.r_female) varwidth(35)

* replicate LeFoulon/Householder analysis, Figure 2
* FIGHT CORRUPTION
* Uruguay
regress vote r_female_i if(country==3 & corrupttreat==1), cl(uniq_id)
lincomest r_female_i
est store D1
* Argentina
regress vote r_female_i if(country==1 & corrupttreat==1), cl(uniq_id)
lincomest r_female_i
est store D2
* Chile
regress vote r_female_i if(country==2 & corrupttreat==1), cl(uniq_id)
lincomest r_female_i
est store D3

* test for differences
regress vote i.r_female#i.country if(corrupttreat==3), cl(uniq_id)
estat ic
est store MD1
regress vote i.r_female if(corrupttreat==3), cl(uniq_id)
estat ic
est store MD2
esttab MD1 MD2, aic bic order(0.r_female#2.country 0.r_female#3.country 1.r_female 1.r_female#1.country 1.r_female#2.country 1.r_female#3.country _cons) coeflabels(0.r_female#2.country "Chile" 0.r_female#3.country "Uruguay" 1.r_female#1.country "Argentina x Female" 1.r_female#2.country "Chile x Female" 1.r_female#3.country "Uruguay x Female" 1.r_female "Respondent: Female" _cons "Intercept (Baseline: Argentina)") drop(0.r_female#1.country 0.r_female) varwidth(35)


esttab MA1 MA2 MB1 MB2 MC1 MC2 MD1 MD2 using "pooltest-respondent.tex", replace aic bic order(0.r_female#2.country 0.r_female#3.country 1.r_female 1.r_female#1.country 1.r_female#2.country 1.r_female#3.country _cons) coeflabels(0.r_female#2.country "Chile" 0.r_female#3.country "Uruguay" 1.r_female#1.country "Argentina x Female" 1.r_female#2.country "Chile x Female" 1.r_female#3.country "Uruguay x Female" 1.r_female "Respondent: Female" _cons "Intercept (Baseline: Argentina)") drop(0.r_female#1.country 0.r_female) varwidth(35) mgroups("Bribes" "Bribes w/ Side Benefits" "Widespread Bribes" "Fought Bribes", pattern(1 0 1 0 1 0 1 0)prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles nonotes addnotes("\textit{t} statistics in parentheses. Standard errors clustered by subject." "* p<0.05, ** p<0.01, *** p<0.001")




***** Question 3a: Do female respondents judge female candidates more harshly for bribery compared to male candidates?
** one translation of this question: does being accused of bribery hurt women more than men among female respondents?

* subset of female respondents, look for effect of bribery by candidate gender
regress vote i.corrupttreat##female_i i.country [pw=weight1500] if(r_female_i == 1), cl(uniq_id)
est store linmod5
* calculate effect of being female in each treatment
lincomest 1.female_i
est store A
est restore linmod5
lincomest 1.female_i + 2.corrupttreat#1.female_i
est store B
est restore linmod5
lincomest 1.female_i + 3.corrupttreat#1.female_i
est store C
est restore linmod5
lincomest 1.female_i + 4.corrupttreat#1.female_i
est store D
est restore linmod5

regress vote i.corrupttreat##female_i i.country [pw=weight1500] if(r_female_i == 0), cl(uniq_id)
est store linmod6
* calculate effect of being female in each treatment
lincomest 1.female_i
est store AA
est restore linmod6
lincomest 1.female_i + 2.corrupttreat#1.female_i
est store BB
est restore linmod6
lincomest 1.female_i + 3.corrupttreat#1.female_i
est store CC
est restore linmod6
lincomest 1.female_i + 4.corrupttreat#1.female_i
est store DD
est restore linmod6

* calculate bonferroni correction 
display 100 - 5/12
* graph bonferroni-corrected CIs
coefplot (A, rename( (1) = "Resist Bribes") \ B, rename( (1) = "Bribes") \ C, rename( (1) = "Bribes Common") \ D, rename( (1) = "Bribes with Jobs") \, label(Female Respondents)) (AA, rename( (1) = "Resist Bribes") \ BB, rename( (1) = "Bribes") \ CC, rename( (1) = "Bribes Common") \ DD, rename( (1) = "Bribes with Jobs") \, label(Male Respondents)) (AAA, rename( (1) = "Resist Bribes") \ BBB, rename( (1) = "Bribes") \ CCC, rename( (1) = "Bribes Common") \ DDD, rename( (1) = "Bribes with Jobs") \, label(All Respondents)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.5) aspect(0.8) levels(99.583) xscale(range(-.15, .15)) xlabel(-.15(0.05).15)

graph export "candidate-gender-by-respondent.pdf", replace




* consolidate by bribe treatment
regress vote i.corrupttreat i.female_i bribeXfemale i.country [pw=weight1500] if(r_female_i == 1), cl(uniq_id)
est store linmod7
lincomest 1.female_i
est store A
est restore linmod7
lincomest 1.female_i + bribeXfemale
est store B
est restore linmod7

regress vote i.corrupttreat i.female_i bribeXfemale i.country [pw=weight1500] if(r_female_i == 0), cl(uniq_id)
est store linmod8
lincomest 1.female_i
est store AA
est restore linmod8
lincomest 1.female_i + bribeXfemale
est store BB
est restore linmod8

regress vote i.corrupttreat i.female_i bribeXfemale i.country [pw=weight1500], cl(uniq_id)
est store linmod2
lincomest 1.female_i
est store AAA
est restore linmod2
lincomest 1.female_i + bribeXfemale
est store BBB
est restore linmod2

* calculate bonferroni correction 
display 100 - 5/6
display 100 - 20/6
* graph bonferroni-corrected CIs
coefplot (A, rename( (1) = "Resist Bribes") \ B, rename( (1) = "All Bribe Treatments") \, label(Female Respondents)) (AA, rename( (1) = "Resist Bribes") \ BB, rename( (1) = "All Bribe Treatments") \, label(Male Respondents)) (AAA, rename( (1) = "Resist Bribes") \ BBB, rename( (1) = "All Bribe Treatments") \, label(All Respondents)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | candidate female) - Pr(vote for candidate | candidate male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.2) aspect(0.8) levels(99.167 96.667) xscale(range(-.15, .1)) xlabel(-.15(0.05).1)

graph export "candidate-gender-by-respondent-simple.pdf", replace

esttab linmod linmod2 linmod5 linmod7 linmod6 linmod8 using fem-cand-table.tex, aic bic replace label nobaselevels interaction(" X ") varwidth(50) order(2.corrupttreat 3.corrupttreat 4.corrupttreat 1.female_i 2.corrupttreat#1.female_i 3.corrupttreat#1.female_i 4.corrupttreat#1.female_i bribeXfemale) coeflabels(2.corrupttreat#1.female_i "Bribes X C: Female" 3.corrupttreat#1.female_i "Bribes common X C: Female" 4.corrupttreat#1.female_i "Bribes but jobs X C: Female") mgroups("All Respondents" "Female Respondents" "Male Respondents", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles nonotes addnotes("\textit{t} statistics in parentheses. Standard errors clustered by subject." "* p<0.05, ** p<0.01, *** p<0.001")



***** Question 3b: Do male respondents judge female candidates more harshly for bribery compared to male candidates?
* subset of female respondents, look for effect of bribery by candidate gender

regress vote i.corrupttreat##r_female_i i.country [pw=weight1500] if(female_i == 1), cl(uniq_id)
est store linmod9
* calculate effect of being female in each treatment
lincomest 1.r_female_i
est store A
est restore linmod9
lincomest 1.r_female_i + 2.corrupttreat#1.r_female_i
est store B
est restore linmod9
lincomest 1.r_female_i + 3.corrupttreat#1.r_female_i
est store C
est restore linmod9
lincomest 1.r_female_i + 4.corrupttreat#1.r_female_i
est store D
est restore linmod9

regress vote i.corrupttreat##r_female_i i.country [pw=weight1500] if(female_i == 0), cl(uniq_id)
est store linmod10
* calculate effect of being female in each treatment
lincomest 1.r_female_i
est store AA
est restore linmod10
lincomest 1.r_female_i + 2.corrupttreat#1.r_female_i
est store BB
est restore linmod10
lincomest 1.r_female_i + 3.corrupttreat#1.r_female_i
est store CC
est restore linmod10
lincomest 1.r_female_i + 4.corrupttreat#1.r_female_i
est store DD
est restore linmod10

regress vote i.corrupttreat##r_female_i i.country [pw=weight1500], cl(uniq_id)
est store linmod3
* calculate effect of being female in each treatment
lincomest 1.r_female_i
est store AAA
est restore linmod3
lincomest 1.r_female_i + 2.corrupttreat#1.r_female_i
est store BBB
est restore linmod3
lincomest 1.r_female_i + 3.corrupttreat#1.r_female_i
est store CCC
est restore linmod3
lincomest 1.r_female_i + 4.corrupttreat#1.r_female_i
est store DDD
est restore linmod3

* calculate bonferroni correction 
display 100 - 5/12
* graph bonferroni-corrected CIs
coefplot (A, rename( (1) = "Resist Bribes") \ B, rename( (1) = "Bribes") \ C, rename( (1) = "Bribes Common") \ D, rename( (1) = "Bribes with Jobs") \, label(Female Candidates)) (AA, rename( (1) = "Resist Bribes") \ BB, rename( (1) = "Bribes") \ CC, rename( (1) = "Bribes Common") \ DD, rename( (1) = "Bribes with Jobs") \, label(Male Candidates)) (AAA, rename( (1) = "Resist Bribes") \ BBB, rename( (1) = "Bribes") \ CCC, rename( (1) = "Bribes Common") \ DDD, rename( (1) = "Bribes with Jobs") \, label(All Candidates)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | respondent female) - Pr(vote for candidate | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.5) aspect(0.8) levels(99.583)

graph export "respondent-gender-by-candidate.pdf", replace


regress vote i.corrupttreat i.r_female_i bribeXr_female i.country [pw=weight1500] if(female_i == 1), cl(uniq_id)
est store linmod11
lincomest 1.r_female_i
est store A 
est restore linmod11
lincomest 1.r_female_i + bribeXr_female
est store B

regress vote i.corrupttreat i.r_female_i bribeXr_female i.country [pw=weight1500] if(female_i == 0), cl(uniq_id)
est store linmod12
lincomest 1.r_female_i
est store AA 
est restore linmod12
lincomest 1.r_female_i + bribeXr_female
est store BB

regress vote i.corrupttreat i.r_female_i bribeXr_female i.country [pw=weight1500], cl(uniq_id)
est store linmod4
lincomest 1.r_female_i
est store AAA 
est restore linmod4
lincomest 1.r_female_i + bribeXr_female
est store BBB

* calculate bonferroni correction 
display 100 - 5/6
display 100 - 20/6
* graph bonferroni-corrected CIs
coefplot (A, rename( (1) = "Resist Bribes") \ B, rename( (1) = "All Bribe Treatments") \, label(Female Candidates)) (AA, rename( (1) = "Resist Bribes") \ BB, rename( (1) = "All Bribe Treatments") \, label(Male Candidates)) (AAA, rename( (1) = "Resist Bribes") \ BBB, rename( (1) = "All Bribe Treatments") \, label(All Candidates)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | respondent female) - Pr(vote for candidate | respondent male)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.2) aspect(0.8) levels(99.167 96.667) xscale(range(-.15 .1)) xlabel(-.15(.05).1)

graph export "respondent-gender-by-candidate-simple.pdf", replace

esttab linmod3 linmod4 linmod9 linmod11 linmod10 linmod12 using fem-resp-table.tex, aic bic replace label nobaselevels interaction(" X ") varwidth(50) order(2.corrupttreat 3.corrupttreat 4.corrupttreat 1.r_female_i 2.corrupttreat#1.r_female_i 3.corrupttreat#1.r_female_i 4.corrupttreat#1.r_female_i bribeXr_female) coeflabels(2.corrupttreat#1.r_female_i "Bribes X R: Female" 3.corrupttreat#1.r_female_i "Bribes common X R: Female" 4.corrupttreat#1.r_female_i "Bribes but jobs X R: Female") mgroups("All Candidates" "Female Candidates" "Male Candidates", pattern(1 0 1 0 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles nonotes addnotes("\textit{t} statistics in parentheses. Standard errors clustered by subject." "* p<0.05, ** p<0.01, *** p<0.001")




***** Question 3a/b variant:
***** Fully interacted model 
gen bribeXfemaleXr_female = bribe_i * female_i * r_female_i
gen femaleXresp = female_i * r_female_i

regress vote female_i r_female_i femaleXresp bribe_i bribeXfemale bribeXr_female bribeXfemaleXr_female i.country [pw=weight1500], cl(uniq_id)
est store linmod

esttab linmod using fully-interacted.tex, aic bic replace varwidth(30) nobaselevels coeflabels(female_i "Candidate: Female" r_female_i "Respondent: Female" femaleXresp "C: Female X R: Female" bribe_i "All Bribe Treatments" bribeXfemale "Bribe X C: Female" bribeXr_female "Bribe X R: Female" bribeXfemaleXr_female "Bribe X C: Female X R: Female" 2.country "Chile" 3.country "Uruguay" _cons "Constant") mtitles(" ") nonumbers



* male R, male C
lincomest bribe_i
est store maleRmaleC
est restore linmod
* male R, female C
lincomest bribe_i + bribeXfemale
est store maleRfemaleC
est restore linmod
* difference
lincomest bribeXfemale
est store malediff
est restore linmod

* female R, male C
lincomest bribe_i + bribeXr_female
est store femaleRmaleC
est restore linmod
* female R, female C
lincomest bribe_i + bribeXfemale + bribeXr_female + bribeXfemaleXr_female
est store femaleRfemaleC
est restore linmod
lincomest bribeXfemale + bribeXfemaleXr_female
est store femalediff
est restore linmod

* calculate bonferroni correction
display 100 - 5/4
display 100 - 20/4

coefplot (maleRmaleC, rename( (1) = "Male Respondent") \ femaleRmaleC, rename( (1) = "Female Respondent") \, label(Male Candidates)) (maleRfemaleC, rename( (1) = "Male Respondent") \ femaleRfemaleC, rename( (1) = "Female Respondent") \, label(Female Candidates)), drop(_cons) scheme(s1manual) ytitle("") xtitle("Pr(vote for candidate | accepted bribes) - Pr(vote for candidate | fought bribes)", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.2) aspect(0.8) levels(98.75 95) xlabel(-0.45(0.05)-0.2)

graph export "bribe-penalty-by-gender-RandC.pdf", replace

* calculate bonferroni correction
display 100 - 5/2
display 100 - 20/2

coefplot (malediff, rename( (1) = "Male Respondent   ")) (femalediff, rename( (1) = "Female Respondent   ")), drop(_cons) scheme(s1manual) ytitle("") xtitle("Difference in Pr(vote) penalty for bribery, Female Candidate - Male Candidate", size(small)) yla(, tlength(0)) xline(0, lpattern(shortdash)) coeflabels(female_i = " ") legend(size(small)) ysize(3) xsize(4.2) aspect(0.8) levels(97.5 90) xlabel(-0.1(0.05)0.15) legend(off)

graph export "bribe-penalty-difference-by-gender-RandC.pdf", replace


***** do men and women treat female candidates differently?
***** what about among non-bribery treatments?
* ME of female candidate, no bribe treatment, respondent female
lincom female_i + femaleXresp*(1) + bribeXfemale*(0) + bribeXfemaleXr_female*(1)*(0)
* ME of female candidate, no bribe treatment, respondent male
lincom female_i + femaleXresp*(0) + bribeXfemale*(0) + bribeXfemaleXr_female*(0)*(0)
* women always treated the same under no bribery, regardless of respondent gender

* respondent gender not a statistically significant influence
lincom (female_i + femaleXresp*(1) + bribeXfemale*(0) + bribeXfemaleXr_female*(1)*(0)) - (female_i + femaleXresp*(0) + bribeXfemale*(0) + bribeXfemaleXr_female*(0)*(0))



***** are male and female candidates treated differently
***** when suspected of bribes?
***** different treatment by female respondents
* ME of bribes, female candidate, female respondent
lincom bribe_i + bribeXfemale*(1) + bribeXr_female*(1) + bribeXfemaleXr_female*(1)*(1)

* ME of bribes, male candidate, female respondent
lincom bribe_i + bribeXfemale*(0) + bribeXr_female*(1) + bribeXfemaleXr_female*(0)*(1)
* bribes are a strong negative impact on all cadnidates regardless of candidate gender

* is the difference statistically significant?
lincom (bribe_i + bribeXfemale*(1) + bribeXr_female*(1) + bribeXfemaleXr_female*(1)*(1)) - (bribe_i + bribeXfemale*(0) + bribeXr_female*(1) + bribeXfemaleXr_female*(0)*(1))
* no, although most of the 95% CI is positive. An 80% CI would be "significant."

***** are male and female candidates treated differently
***** when suspected of bribes?
***** different treatment by male respondents
* ME of bribes, female candidate, male respondent
lincom bribe_i + bribeXfemale*(1) + bribeXr_female*(0) + bribeXfemaleXr_female*(1)*(0)

* ME of bribes, male candidate, male respondent
lincom bribe_i + bribeXfemale*(0) + bribeXr_female*(0) + bribeXfemaleXr_female*(0)*(0)
* bribes are a strong negative impact on all cadnidates regardless of candidate gender

* is the difference statistically significant?
lincom (bribe_i + bribeXfemale*(1) + bribeXr_female*(0) + bribeXfemaleXr_female*(1)*(0)) - (bribe_i + bribeXfemale*(0) + bribeXr_female*(0) + bribeXfemaleXr_female*(0)*(0))
* no; among male respondents, there is no meaningful evidence that bribes affect women candidates more strongly.


* Create summary table
tab country, generate(country_i)
tab corrupttreat, gen(treatdum)
estpost sum vote female_i r_female_i country_i* treatdum*
esttab using summary-table.tex, replace varwidth(30) cell((mean(fmt(a3) label(Mean)) sd(label(SD)) sum(label(Sum)))) nonumber nomtitle coeflabels(vote "Vote for Candidate" female_i "Candidate: Female" r_female_i "Respondent: Female" country_i1 "Argentina" country_i2 "Chile" country_i3 "Uruguay" treatdum1 "Treatment: Fought bribery" treatdum2 "Treatment: Bribes" treatdum3 "Treatment: Bribes common" treatdum4 "Treatment: Bribes but jobs")

log close





